/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __BIND_PERM_SKEL_H__
#define __BIND_PERM_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct bind_perm {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_program *bind_v4_prog;
		struct bpf_program *bind_v6_prog;
	} progs;
	struct {
		struct bpf_link *bind_v4_prog;
		struct bpf_link *bind_v6_prog;
	} links;
};

static void
bind_perm__destroy(struct bind_perm *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
bind_perm__create_skeleton(struct bind_perm *obj);

static inline struct bind_perm *
bind_perm__open_opts(const struct bpf_object_open_opts *opts)
{
	struct bind_perm *obj;

	obj = (struct bind_perm *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (bind_perm__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	bind_perm__destroy(obj);
	return NULL;
}

static inline struct bind_perm *
bind_perm__open(void)
{
	return bind_perm__open_opts(NULL);
}

static inline int
bind_perm__load(struct bind_perm *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct bind_perm *
bind_perm__open_and_load(void)
{
	struct bind_perm *obj;

	obj = bind_perm__open();
	if (!obj)
		return NULL;
	if (bind_perm__load(obj)) {
		bind_perm__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
bind_perm__attach(struct bind_perm *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
bind_perm__detach(struct bind_perm *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
bind_perm__create_skeleton(struct bind_perm *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "bind_perm";
	s->obj = &obj->obj;

	/* programs */
	s->prog_cnt = 2;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "bind_v4_prog";
	s->progs[0].prog = &obj->progs.bind_v4_prog;
	s->progs[0].link = &obj->links.bind_v4_prog;

	s->progs[1].name = "bind_v6_prog";
	s->progs[1].prog = &obj->progs.bind_v6_prog;
	s->progs[1].link = &obj->links.bind_v6_prog;

	s->data_sz = 8160;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xe0\x19\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x18\0\
\x01\0\xb7\0\0\0\0\0\0\0\x79\x12\x40\0\0\0\0\0\x15\x02\x08\0\0\0\0\0\x61\x22\
\x04\0\0\0\0\0\x55\x02\x06\0\x02\0\0\0\x61\x12\x20\0\0\0\0\0\x55\x02\x04\0\x01\
\0\0\0\x61\x11\x18\0\0\0\0\0\xb7\0\0\0\x03\0\0\0\x15\x01\x01\0\0\x6f\0\0\xb7\0\
\0\0\x01\0\0\0\x95\0\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x79\x12\x40\0\0\0\0\0\x15\
\x02\x08\0\0\0\0\0\x61\x22\x04\0\0\0\0\0\x55\x02\x06\0\x0a\0\0\0\x61\x12\x20\0\
\0\0\0\0\x55\x02\x04\0\x01\0\0\0\x61\x11\x18\0\0\0\0\0\xb7\0\0\0\x03\0\0\0\x15\
\x01\x01\0\0\x6f\0\0\xb7\0\0\0\x01\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\xff\
\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\
\x01\0\x51\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x01\0\x51\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x20\0\0\0\0\0\0\0\x01\0\x52\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xff\xff\xff\xff\
\xff\xff\xff\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x01\0\x51\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x01\0\x51\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x20\0\0\0\0\
\0\0\0\x01\0\x52\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x11\x01\x25\x0e\x13\x05\
\x03\x0e\x10\x17\x1b\x0e\x11\x01\x55\x17\0\0\x02\x34\0\x03\x0e\x49\x13\x3f\x19\
\x3a\x0b\x3b\x0b\x02\x18\0\0\x03\x01\x01\x49\x13\0\0\x04\x21\0\x49\x13\x37\x0b\
\0\0\x05\x24\0\x03\x0e\x3e\x0b\x0b\x0b\0\0\x06\x24\0\x03\x0e\x0b\x0b\x3e\x0b\0\
\0\x07\x04\x01\x49\x13\x03\x0e\x0b\x0b\x3a\x0b\x3b\x0b\0\0\x08\x28\0\x03\x0e\
\x1c\x0f\0\0\x09\x16\0\x49\x13\x03\x0e\x3a\x0b\x3b\x0b\0\0\x0a\x2e\x01\x03\x0e\
\x3a\x0b\x3b\x0b\x27\x19\x49\x13\x20\x0b\0\0\x0b\x05\0\x03\x0e\x3a\x0b\x3b\x0b\
\x49\x13\0\0\x0c\x34\0\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\x0d\x0f\0\x49\x13\0\
\0\x0e\x13\x01\x03\x0e\x0b\x0b\x3a\x0b\x3b\x05\0\0\x0f\x0d\0\x03\x0e\x49\x13\
\x3a\x0b\x3b\x05\x38\x0b\0\0\x10\x0d\0\x49\x13\x3a\x0b\x3b\x05\x88\x01\x0f\x38\
\x0b\0\0\x11\x17\x01\x0b\x0b\x3a\x0b\x3b\x05\x88\x01\x0f\0\0\x12\x2e\x01\x11\
\x01\x12\x06\x40\x18\x97\x42\x19\x03\x0e\x3a\x0b\x3b\x0b\x27\x19\x49\x13\x3f\
\x19\0\0\x13\x05\0\x02\x17\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\x14\x1d\x01\x31\
\x13\x11\x01\x12\x06\x58\x0b\x59\x0b\x57\x0b\0\0\x15\x05\0\x02\x17\x31\x13\0\0\
\x16\x05\0\x1c\x0d\x31\x13\0\0\x17\x34\0\x02\x17\x31\x13\0\0\0\x1f\x03\0\0\x04\
\0\0\0\0\0\x08\x01\0\0\0\0\x0c\0\x45\0\0\0\0\0\0\0\x57\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x02\xbc\0\0\0\x3f\0\0\0\x01\x2d\x09\x03\0\0\0\0\0\0\0\0\x03\x4b\0\0\0\
\x04\x52\0\0\0\x04\0\x05\xc5\0\0\0\x06\x01\x06\xca\0\0\0\x08\x07\x07\x9f\0\0\0\
\x54\x01\0\0\x04\x02\x18\x08\xeb\0\0\0\x01\x08\xf7\0\0\0\x02\x08\x02\x01\0\0\
\x03\x08\x0b\x01\0\0\x04\x08\x14\x01\0\0\x05\x08\x23\x01\0\0\x06\x08\x2d\x01\0\
\0\x0a\x08\x39\x01\0\0\x80\x80\x20\x08\x46\x01\0\0\x80\x10\0\x05\xde\0\0\0\x07\
\x04\x09\xb1\0\0\0\x71\x01\0\0\x03\x18\x05\x62\x01\0\0\x07\x02\x0a\x77\x01\0\0\
\x01\x0a\xe6\0\0\0\x01\x0b\x85\x01\0\0\x01\x0a\xed\0\0\0\x0b\xb7\x01\0\0\x01\
\x0a\xe6\0\0\0\x0c\xe4\x01\0\0\x01\x0c\xa6\x01\0\0\0\x05\x81\x01\0\0\x05\x04\
\x0d\xf2\0\0\0\x0e\x5a\x02\0\0\x48\x04\x26\x12\x0f\x89\x01\0\0\x8f\x01\0\0\x04\
\x27\x12\0\x0f\x9b\x01\0\0\x8f\x01\0\0\x04\x28\x12\x04\x0f\xa4\x01\0\0\x9a\x01\
\0\0\x04\x2b\x12\x08\x0f\xad\x01\0\0\x8f\x01\0\0\x04\x2e\x12\x18\x0f\xb7\x01\0\
\0\x8f\x01\0\0\x04\x31\x12\x1c\x0f\xbe\x01\0\0\x8f\x01\0\0\x04\x32\x12\x20\x0f\
\xc3\x01\0\0\x8f\x01\0\0\x04\x33\x12\x24\x0f\xcc\x01\0\0\x8f\x01\0\0\x04\x34\
\x12\x28\x0f\xd8\x01\0\0\x9a\x01\0\0\x04\x37\x12\x2c\x10\x7a\x01\0\0\x04\x3a\
\x12\x08\x40\x11\x08\x04\x3a\x12\x08\x0f\xe4\x01\0\0\xa6\x01\0\0\x04\x3a\x12\0\
\0\0\x09\x9f\0\0\0\x95\x01\0\0\x03\x1b\x03\x8f\x01\0\0\x04\x52\0\0\0\x04\0\x0d\
\xab\x01\0\0\x0e\x51\x02\0\0\x50\x04\0\x11\x0f\xe7\x01\0\0\x8f\x01\0\0\x04\x01\
\x11\0\x0f\xb7\x01\0\0\x8f\x01\0\0\x04\x02\x11\x04\x0f\xbe\x01\0\0\x8f\x01\0\0\
\x04\x03\x11\x08\x0f\xc3\x01\0\0\x8f\x01\0\0\x04\x04\x11\x0c\x0f\xf4\x01\0\0\
\x8f\x01\0\0\x04\x05\x11\x10\x0f\xf9\x01\0\0\x8f\x01\0\0\x04\x06\x11\x14\x0f\
\x02\x02\0\0\x8f\x01\0\0\x04\x08\x11\x18\x0f\x0a\x02\0\0\x9a\x01\0\0\x04\x09\
\x11\x1c\x0f\x12\x02\0\0\x8f\x01\0\0\x04\x0a\x11\x2c\x0f\x1b\x02\0\0\x8f\x01\0\
\0\x04\x0b\x11\x30\x0f\x24\x02\0\0\x8f\x01\0\0\x04\x0c\x11\x34\x0f\x2c\x02\0\0\
\x9a\x01\0\0\x04\x0d\x11\x38\x0f\x34\x02\0\0\x8f\x01\0\0\x04\x0e\x11\x48\x0f\
\x3a\x02\0\0\x6b\x02\0\0\x04\x0f\x11\x4c\0\x09\xe6\0\0\0\x4b\x02\0\0\x03\x1a\
\x12\0\0\0\0\0\0\0\0\x60\0\0\0\x01\x5a\x68\x02\0\0\x01\x22\xe6\0\0\0\x13\0\0\0\
\0\x85\x01\0\0\x01\x22\xed\0\0\0\x14\xb8\0\0\0\x08\0\0\0\0\0\0\0\x48\0\0\0\x01\
\x24\x09\x15\x33\0\0\0\xc4\0\0\0\x16\x02\xcf\0\0\0\x17\x66\0\0\0\xda\0\0\0\0\0\
\x12\0\0\0\0\0\0\0\0\x60\0\0\0\x01\x5a\x75\x02\0\0\x01\x28\xe6\0\0\0\x13\x99\0\
\0\0\x85\x01\0\0\x01\x28\xed\0\0\0\x14\xb8\0\0\0\x08\0\0\0\0\0\0\0\x48\0\0\0\
\x01\x2a\x09\x15\xcc\0\0\0\xc4\0\0\0\x16\x0a\xcf\0\0\0\x17\xff\0\0\0\xda\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x6c\x61\x6e\x67\x20\x76\x65\x72\x73\x69\x6f\
\x6e\x20\x31\x32\x2e\x30\x2e\x31\x20\x28\x52\x65\x64\x20\x48\x61\x74\x20\x31\
\x32\x2e\x30\x2e\x31\x2d\x34\x2e\x6d\x6f\x64\x75\x6c\x65\x5f\x65\x6c\x38\x2e\
\x36\x2e\x30\x2b\x31\x30\x32\x34\x2b\x32\x64\x38\x36\x36\x33\x64\x38\x29\0\x70\
\x72\x6f\x67\x73\x2f\x62\x69\x6e\x64\x5f\x70\x65\x72\x6d\x2e\x63\0\x2f\x62\x75\
\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\
\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x35\x32\x2e\x65\
\x6c\x38\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x35\x32\
\x2e\x65\x6c\x38\x73\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\
\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\
\x70\x66\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\
\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x75\x6e\x73\x69\
\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x53\x4f\x43\x4b\x5f\x53\x54\x52\x45\x41\x4d\
\0\x53\x4f\x43\x4b\x5f\x44\x47\x52\x41\x4d\0\x53\x4f\x43\x4b\x5f\x52\x41\x57\0\
\x53\x4f\x43\x4b\x5f\x52\x44\x4d\0\x53\x4f\x43\x4b\x5f\x53\x45\x51\x50\x41\x43\
\x4b\x45\x54\0\x53\x4f\x43\x4b\x5f\x44\x43\x43\x50\0\x53\x4f\x43\x4b\x5f\x50\
\x41\x43\x4b\x45\x54\0\x53\x4f\x43\x4b\x5f\x43\x4c\x4f\x45\x58\x45\x43\0\x53\
\x4f\x43\x4b\x5f\x4e\x4f\x4e\x42\x4c\x4f\x43\x4b\0\x5f\x5f\x73\x6f\x63\x6b\x65\
\x74\x5f\x74\x79\x70\x65\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x73\x68\x6f\x72\
\x74\0\x5f\x5f\x75\x31\x36\0\x62\x69\x6e\x64\x5f\x70\x72\x6f\x67\0\x69\x6e\x74\
\0\x63\x74\x78\0\x75\x73\x65\x72\x5f\x66\x61\x6d\x69\x6c\x79\0\x5f\x5f\x75\x33\
\x32\0\x75\x73\x65\x72\x5f\x69\x70\x34\0\x75\x73\x65\x72\x5f\x69\x70\x36\0\x75\
\x73\x65\x72\x5f\x70\x6f\x72\x74\0\x66\x61\x6d\x69\x6c\x79\0\x74\x79\x70\x65\0\
\x70\x72\x6f\x74\x6f\x63\x6f\x6c\0\x6d\x73\x67\x5f\x73\x72\x63\x5f\x69\x70\x34\
\0\x6d\x73\x67\x5f\x73\x72\x63\x5f\x69\x70\x36\0\x73\x6b\0\x62\x6f\x75\x6e\x64\
\x5f\x64\x65\x76\x5f\x69\x66\0\x6d\x61\x72\x6b\0\x70\x72\x69\x6f\x72\x69\x74\
\x79\0\x73\x72\x63\x5f\x69\x70\x34\0\x73\x72\x63\x5f\x69\x70\x36\0\x73\x72\x63\
\x5f\x70\x6f\x72\x74\0\x64\x73\x74\x5f\x70\x6f\x72\x74\0\x64\x73\x74\x5f\x69\
\x70\x34\0\x64\x73\x74\x5f\x69\x70\x36\0\x73\x74\x61\x74\x65\0\x72\x78\x5f\x71\
\x75\x65\x75\x65\x5f\x6d\x61\x70\x70\x69\x6e\x67\0\x5f\x5f\x73\x33\x32\0\x62\
\x70\x66\x5f\x73\x6f\x63\x6b\0\x62\x70\x66\x5f\x73\x6f\x63\x6b\x5f\x61\x64\x64\
\x72\0\x62\x69\x6e\x64\x5f\x76\x34\x5f\x70\x72\x6f\x67\0\x62\x69\x6e\x64\x5f\
\x76\x36\x5f\x70\x72\x6f\x67\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\xa4\x01\0\0\xa4\
\x01\0\0\x75\x02\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\x01\0\0\0\x0a\0\0\x04\x48\0\0\
\0\x0f\0\0\0\x03\0\0\0\0\0\0\0\x1b\0\0\0\x03\0\0\0\x20\0\0\0\x24\0\0\0\x05\0\0\
\0\x40\0\0\0\x2d\0\0\0\x03\0\0\0\xc0\0\0\0\x37\0\0\0\x03\0\0\0\xe0\0\0\0\x3e\0\
\0\0\x03\0\0\0\0\x01\0\0\x43\0\0\0\x03\0\0\0\x20\x01\0\0\x4c\0\0\0\x03\0\0\0\
\x40\x01\0\0\x58\0\0\0\x05\0\0\0\x60\x01\0\0\0\0\0\0\x07\0\0\0\0\x02\0\0\x64\0\
\0\0\0\0\0\x08\x04\0\0\0\x6a\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\0\x03\0\0\0\x06\0\0\0\x04\0\0\0\x77\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\
\0\0\0\0\0\0\x01\0\0\x05\x08\0\0\0\x8b\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x02\x12\0\0\0\0\0\0\0\x01\0\0\x0d\x0a\0\0\0\x8e\0\0\0\x01\0\0\0\x92\0\0\0\0\0\
\0\x01\x04\0\0\0\x20\0\0\x01\x96\0\0\0\x01\0\0\x0c\x09\0\0\0\0\0\0\0\x01\0\0\
\x0d\x0a\0\0\0\x8e\0\0\0\x01\0\0\0\xee\x01\0\0\x01\0\0\x0c\x0c\0\0\0\x56\x02\0\
\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x0e\0\0\0\x06\0\0\
\0\x04\0\0\0\x5b\x02\0\0\0\0\0\x0e\x0f\0\0\0\x01\0\0\0\x64\x02\0\0\x01\0\0\x0f\
\0\0\0\0\x10\0\0\0\0\0\0\0\x04\0\0\0\x6c\x02\0\0\0\0\0\x07\0\0\0\0\0\x62\x70\
\x66\x5f\x73\x6f\x63\x6b\x5f\x61\x64\x64\x72\0\x75\x73\x65\x72\x5f\x66\x61\x6d\
\x69\x6c\x79\0\x75\x73\x65\x72\x5f\x69\x70\x34\0\x75\x73\x65\x72\x5f\x69\x70\
\x36\0\x75\x73\x65\x72\x5f\x70\x6f\x72\x74\0\x66\x61\x6d\x69\x6c\x79\0\x74\x79\
\x70\x65\0\x70\x72\x6f\x74\x6f\x63\x6f\x6c\0\x6d\x73\x67\x5f\x73\x72\x63\x5f\
\x69\x70\x34\0\x6d\x73\x67\x5f\x73\x72\x63\x5f\x69\x70\x36\0\x5f\x5f\x75\x33\
\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\
\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x73\x6b\0\x63\x74\
\x78\0\x69\x6e\x74\0\x62\x69\x6e\x64\x5f\x76\x34\x5f\x70\x72\x6f\x67\0\x63\x67\
\x72\x6f\x75\x70\x2f\x62\x69\x6e\x64\x34\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\
\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\
\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x35\x32\x2e\x65\x6c\x38\x2f\x6c\x69\x6e\
\x75\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x35\x32\x2e\x65\x6c\x38\x73\x2e\
\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\
\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\
\x67\x73\x2f\x62\x69\x6e\x64\x5f\x70\x65\x72\x6d\x2e\x63\0\x69\x6e\x74\x20\x62\
\x69\x6e\x64\x5f\x76\x34\x5f\x70\x72\x6f\x67\x28\x73\x74\x72\x75\x63\x74\x20\
\x62\x70\x66\x5f\x73\x6f\x63\x6b\x5f\x61\x64\x64\x72\x20\x2a\x63\x74\x78\x29\0\
\x09\x73\x6b\x20\x3d\x20\x63\x74\x78\x2d\x3e\x73\x6b\x3b\0\x09\x69\x66\x20\x28\
\x21\x73\x6b\x29\0\x09\x69\x66\x20\x28\x73\x6b\x2d\x3e\x66\x61\x6d\x69\x6c\x79\
\x20\x21\x3d\x20\x66\x61\x6d\x69\x6c\x79\x29\0\x09\x69\x66\x20\x28\x63\x74\x78\
\x2d\x3e\x74\x79\x70\x65\x20\x21\x3d\x20\x53\x4f\x43\x4b\x5f\x53\x54\x52\x45\
\x41\x4d\x29\0\x09\x69\x66\x20\x28\x63\x74\x78\x2d\x3e\x75\x73\x65\x72\x5f\x70\
\x6f\x72\x74\x20\x3d\x3d\x20\x62\x70\x66\x5f\x68\x74\x6f\x6e\x73\x28\x31\x31\
\x31\x29\x29\0\x09\x72\x65\x74\x75\x72\x6e\x20\x62\x69\x6e\x64\x5f\x70\x72\x6f\
\x67\x28\x63\x74\x78\x2c\x20\x41\x46\x5f\x49\x4e\x45\x54\x29\x3b\0\x62\x69\x6e\
\x64\x5f\x76\x36\x5f\x70\x72\x6f\x67\0\x63\x67\x72\x6f\x75\x70\x2f\x62\x69\x6e\
\x64\x36\0\x69\x6e\x74\x20\x62\x69\x6e\x64\x5f\x76\x36\x5f\x70\x72\x6f\x67\x28\
\x73\x74\x72\x75\x63\x74\x20\x62\x70\x66\x5f\x73\x6f\x63\x6b\x5f\x61\x64\x64\
\x72\x20\x2a\x63\x74\x78\x29\0\x09\x72\x65\x74\x75\x72\x6e\x20\x62\x69\x6e\x64\
\x5f\x70\x72\x6f\x67\x28\x63\x74\x78\x2c\x20\x41\x46\x5f\x49\x4e\x45\x54\x36\
\x29\x3b\0\x63\x68\x61\x72\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x6c\x69\x63\x65\
\x6e\x73\x65\0\x62\x70\x66\x5f\x73\x6f\x63\x6b\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\
\0\x24\0\0\0\x24\0\0\0\x54\x01\0\0\x78\x01\0\0\0\0\0\0\x08\0\0\0\xa3\0\0\0\x01\
\0\0\0\0\0\0\0\x0b\0\0\0\xfb\x01\0\0\x01\0\0\0\0\0\0\0\x0d\0\0\0\x10\0\0\0\xa3\
\0\0\0\x0a\0\0\0\0\0\0\0\xb0\0\0\0\x27\x01\0\0\0\x88\0\0\x08\0\0\0\xb0\0\0\0\
\x53\x01\0\0\x0c\x38\0\0\x10\0\0\0\xb0\0\0\0\x62\x01\0\0\x06\x3c\0\0\x18\0\0\0\
\xb0\0\0\0\x6c\x01\0\0\x0a\x48\0\0\x20\0\0\0\xb0\0\0\0\x6c\x01\0\0\x06\x48\0\0\
\x28\0\0\0\xb0\0\0\0\x87\x01\0\0\x0b\x54\0\0\x30\0\0\0\xb0\0\0\0\x87\x01\0\0\
\x06\x54\0\0\x38\0\0\0\xb0\0\0\0\xa6\x01\0\0\x0b\x6c\0\0\x48\0\0\0\xb0\0\0\0\0\
\0\0\0\0\0\0\0\x58\0\0\0\xb0\0\0\0\xcd\x01\0\0\x02\x90\0\0\xfb\x01\0\0\x0a\0\0\
\0\0\0\0\0\xb0\0\0\0\x08\x02\0\0\0\xa0\0\0\x08\0\0\0\xb0\0\0\0\x53\x01\0\0\x0c\
\x38\0\0\x10\0\0\0\xb0\0\0\0\x62\x01\0\0\x06\x3c\0\0\x18\0\0\0\xb0\0\0\0\x6c\
\x01\0\0\x0a\x48\0\0\x20\0\0\0\xb0\0\0\0\x6c\x01\0\0\x06\x48\0\0\x28\0\0\0\xb0\
\0\0\0\x87\x01\0\0\x0b\x54\0\0\x30\0\0\0\xb0\0\0\0\x87\x01\0\0\x06\x54\0\0\x38\
\0\0\0\xb0\0\0\0\xa6\x01\0\0\x0b\x6c\0\0\x48\0\0\0\xb0\0\0\0\0\0\0\0\0\0\0\0\
\x58\0\0\0\xb0\0\0\0\x34\x02\0\0\x02\xa8\0\0\0\0\0\x0c\0\0\0\xff\xff\xff\xff\
\x04\0\x08\0\x08\x7c\x0b\0\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\
\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\x56\x01\0\0\x04\0\xde\0\0\
\0\x08\x01\x01\xfb\x0e\x0d\0\x01\x01\x01\x01\0\0\0\x01\0\0\x01\x70\x72\x6f\x67\
\x73\0\x2f\x75\x73\x72\x2f\x69\x6e\x63\x6c\x75\x64\x65\x2f\x62\x69\x74\x73\0\
\x2f\x75\x73\x72\x2f\x69\x6e\x63\x6c\x75\x64\x65\x2f\x61\x73\x6d\x2d\x67\x65\
\x6e\x65\x72\x69\x63\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\
\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\
\x2e\x30\x2d\x33\x35\x32\x2e\x65\x6c\x38\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\
\x31\x38\x2e\x30\x2d\x33\x35\x32\x2e\x65\x6c\x38\x73\x2e\x78\x38\x36\x5f\x36\
\x34\x2f\x74\x6f\x6f\x6c\x73\0\0\x62\x69\x6e\x64\x5f\x70\x65\x72\x6d\x2e\x63\0\
\x01\0\0\x73\x6f\x63\x6b\x65\x74\x5f\x74\x79\x70\x65\x2e\x68\0\x02\0\0\x69\x6e\
\x74\x2d\x6c\x6c\x36\x34\x2e\x68\0\x03\0\0\x69\x6e\x63\x6c\x75\x64\x65\x2f\x75\
\x61\x70\x69\x2f\x6c\x69\x6e\x75\x78\x2f\x62\x70\x66\x2e\x68\0\x04\0\0\0\0\x09\
\x02\0\0\0\0\0\0\0\0\x03\x22\x01\x05\x0c\x0a\x03\x6b\x20\x05\x06\x21\x05\x0a\
\x23\x05\x06\x06\x20\x05\x0b\x06\x23\x05\x06\x06\x20\x05\x0b\x06\x26\x06\x03\
\x65\x20\x05\x02\x06\x03\x24\x3c\x02\x01\0\x01\x01\0\x09\x02\0\0\0\0\0\0\0\0\
\x03\x28\x01\x05\x0c\x0a\x03\x65\x20\x05\x06\x21\x05\x0a\x23\x05\x06\x06\x20\
\x05\x0b\x06\x23\x05\x06\x06\x20\x05\x0b\x06\x26\x06\x03\x65\x20\x05\x02\x06\
\x03\x2a\x3c\x02\x01\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xb0\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe9\0\0\0\
\0\0\x03\0\x58\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe2\0\0\0\0\0\x04\0\x58\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\x0b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x0d\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x12\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x77\0\0\0\x11\0\x05\0\0\0\0\0\0\
\0\0\0\x04\0\0\0\0\0\0\0\x5c\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\
\0\x4f\0\0\0\x12\0\x04\0\0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x01\0\0\0\x04\0\0\0\x3b\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x6e\0\0\0\0\0\0\0\
\x01\0\0\0\x04\0\0\0\xa1\0\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\xd4\0\0\0\0\0\0\0\
\x01\0\0\0\x05\0\0\0\x07\x01\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x06\0\0\0\0\0\0\0\
\x0a\0\0\0\x07\0\0\0\x0c\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x12\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x16\0\0\0\0\0\0\0\x0a\0\0\0\x0b\0\0\0\x1a\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x26\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x2b\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x37\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x4c\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x53\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x5e\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x66\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x6c\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x72\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x78\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x7e\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x84\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x8a\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x90\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x98\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xa0\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\xab\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xb2\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\xb9\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xc5\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\xd0\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xdb\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\xe7\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xf3\0\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\xfc\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x09\x01\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\x16\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x23\x01\0\0\0\0\0\
\0\x0a\0\0\0\x09\0\0\0\x30\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x3d\x01\0\0\0\0\
\0\0\x0a\0\0\0\x09\0\0\0\x4a\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x57\x01\0\0\0\
\0\0\0\x0a\0\0\0\x09\0\0\0\x64\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x81\x01\0\0\
\0\0\0\0\x0a\0\0\0\x09\0\0\0\x94\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xac\x01\0\
\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xb5\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xc2\x01\
\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xcf\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xdc\
\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xe9\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\
\xf6\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x03\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\
\0\x10\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x1d\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\
\0\0\x2a\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x37\x02\0\0\0\0\0\0\x0a\0\0\0\x09\
\0\0\0\x44\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x51\x02\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\x5e\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x70\x02\0\0\0\0\0\0\x0a\0\0\
\0\x09\0\0\0\x77\x02\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x85\x02\0\0\0\0\0\0\x0a\0\
\0\0\x09\0\0\0\x90\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x94\x02\0\0\0\0\0\0\x0a\
\0\0\0\x09\0\0\0\xa3\x02\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\xb3\x02\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\xc2\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\xcd\x02\0\0\0\0\0\
\0\x01\0\0\0\x05\0\0\0\xdb\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xe6\x02\0\0\0\0\
\0\0\x0a\0\0\0\x06\0\0\0\xea\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xf9\x02\0\0\0\
\0\0\0\x01\0\0\0\x05\0\0\0\x09\x03\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x18\x03\0\0\
\0\0\0\0\x0a\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x08\0\0\0\0\0\
\0\0\x01\0\0\0\x04\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x18\0\0\0\0\0\0\
\0\x01\0\0\0\x05\0\0\0\xa8\x01\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\x2c\0\0\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\x3c\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x50\0\0\0\0\0\0\0\0\0\0\
\0\x04\0\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x70\0\0\0\0\0\0\0\0\0\0\0\x04\
\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\
\xa0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xb0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xc0\0\
\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xd0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xe0\0\0\0\0\
\0\0\0\0\0\0\0\x04\0\0\0\xf8\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x08\x01\0\0\0\0\0\
\0\0\0\0\0\x05\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x28\x01\0\0\0\0\0\0\
\0\0\0\0\x05\0\0\0\x38\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x48\x01\0\0\0\0\0\0\0\
\0\0\0\x05\0\0\0\x58\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x68\x01\0\0\0\0\0\0\0\0\
\0\0\x05\0\0\0\x78\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x88\x01\0\0\0\0\0\0\0\0\0\
\0\x05\0\0\0\x14\0\0\0\0\0\0\0\x0a\0\0\0\x0a\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\
\x04\0\0\0\x2c\0\0\0\0\0\0\0\x0a\0\0\0\x0a\0\0\0\x30\0\0\0\0\0\0\0\x01\0\0\0\
\x05\0\0\0\xeb\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x24\x01\0\0\0\0\0\0\x01\0\0\0\
\x05\0\0\0\x0d\x0e\x0c\0\x2e\x64\x65\x62\x75\x67\x5f\x61\x62\x62\x72\x65\x76\0\
\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\x2e\x65\x78\x74\0\x2e\
\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x72\x61\x6e\x67\x65\x73\0\x2e\x64\x65\
\x62\x75\x67\x5f\x73\x74\x72\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x69\
\x6e\x66\x6f\0\x62\x69\x6e\x64\x5f\x76\x36\x5f\x70\x72\x6f\x67\0\x62\x69\x6e\
\x64\x5f\x76\x34\x5f\x70\x72\x6f\x67\0\x2e\x6c\x6c\x76\x6d\x5f\x61\x64\x64\x72\
\x73\x69\x67\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\
\x62\x75\x67\x5f\x6c\x69\x6e\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\
\x66\x72\x61\x6d\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x6c\x6f\x63\
\0\x62\x69\x6e\x64\x5f\x70\x65\x72\x6d\x2e\x63\0\x2e\x73\x74\x72\x74\x61\x62\0\
\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\0\x63\x67\x72\
\x6f\x75\x70\x2f\x62\x69\x6e\x64\x36\0\x4c\x42\x42\x31\x5f\x35\0\x4c\x42\x42\
\x30\x5f\x35\0\x63\x67\x72\x6f\x75\x70\x2f\x62\x69\x6e\x64\x34\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbc\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xe3\x18\0\0\0\0\0\0\xfd\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xf0\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x60\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd5\0\0\0\x01\
\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x78\0\0\0\x01\0\0\0\x03\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa5\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x04\x01\0\0\0\0\0\0\x32\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xa1\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\
\x12\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\x17\0\0\0\x06\0\0\0\x08\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x36\x02\0\0\0\
\0\0\0\x31\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x43\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x67\x03\0\0\0\0\0\0\x23\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3f\0\0\0\
\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\x12\0\0\0\0\0\0\x60\x04\0\0\0\0\
\0\0\x17\0\0\0\x09\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x26\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8a\x06\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xd0\x16\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x17\0\0\0\x0b\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x34\0\0\0\x01\0\0\0\x30\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xba\x06\0\0\0\0\0\0\x82\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\0\0\0\0\x01\0\0\0\0\0\0\0\xd0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x3c\x09\0\0\0\0\0\0\x31\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xcc\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\x17\0\0\0\
\0\0\0\x10\0\0\0\0\0\0\0\x17\0\0\0\x0e\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\
\0\x19\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x6d\x0d\0\0\0\0\0\0\x98\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x15\0\0\0\
\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\x17\0\0\0\0\0\0\x60\x01\0\0\0\0\
\0\0\x17\0\0\0\x10\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x94\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x0f\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x90\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x80\x18\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x17\0\0\0\x12\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x84\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x48\x0f\0\0\0\0\0\0\x5a\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x80\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc0\
\x18\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x17\0\0\0\x14\0\0\0\x08\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\x69\0\0\0\x03\x4c\xff\x6f\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\xe0\
\x18\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\x17\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xc4\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa8\x10\0\0\0\0\0\
\0\x68\x01\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __BIND_PERM_SKEL_H__ */
